==> hbase-2.3.7-src.tar.gz: hbase-2.3.7/hbase-hbtop/src/test/java/org/apache/hadoop/hbase/hbtop/terminal/impl/TestTerminalPrinter.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.hbtop.terminal.impl;

import java.util.concurrent.TimeUnit;

import org.apache.hadoop.hbase.hbtop.terminal.KeyPress;
import org.apache.hadoop.hbase.hbtop.terminal.Terminal;
import org.apache.hadoop.hbase.hbtop.terminal.TerminalPrinter;


public final class TestTerminalPrinter {

  private TestTerminalPrinter() {
  }

  public static void main(String[] args) throws Exception {
    try (Terminal terminal = new TerminalImpl()) {
      terminal.hideCursor();
      terminal.refresh();

      TerminalPrinter printer = terminal.getTerminalPrinter(0);
      printer.print("Normal string").endOfLine();
      printer.startHighlight().print("Highlighted string").stopHighlight().endOfLine();
      printer.startBold().print("Bold string").stopBold().endOfLine();
      printer.startHighlight().startBold().print("Highlighted bold string")
          .stopBold().stopHighlight().endOfLine();
      printer.endOfLine();
      printer.print("Press any key to finish").endOfLine();

      terminal.refresh();

      while (true) {
        KeyPress keyPress = terminal.pollKeyPress();
        if (keyPress == null) {
          TimeUnit.MILLISECONDS.sleep(100);
          continue;
        }
        break;
      }
    }
  }
}

==> hbase-2.5.7-src.tar.gz: hbase-2.5.7/hbase-hbtop/src/test/java/org/apache/hadoop/hbase/hbtop/terminal/impl/TestTerminalPrinter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.hbtop.terminal.impl;

import java.util.concurrent.TimeUnit;
import org.apache.hadoop.hbase.hbtop.terminal.KeyPress;
import org.apache.hadoop.hbase.hbtop.terminal.Terminal;
import org.apache.hadoop.hbase.hbtop.terminal.TerminalPrinter;

public final class TestTerminalPrinter {

  private TestTerminalPrinter() {
  }

  public static void main(String[] args) throws Exception {
    try (Terminal terminal = new TerminalImpl()) {
      terminal.hideCursor();
      terminal.refresh();

      TerminalPrinter printer = terminal.getTerminalPrinter(0);
      printer.print("Normal string").endOfLine();
      printer.startHighlight().print("Highlighted string").stopHighlight().endOfLine();
      printer.startBold().print("Bold string").stopBold().endOfLine();
      printer.startHighlight().startBold().print("Highlighted bold string").stopBold()
        .stopHighlight().endOfLine();
      printer.endOfLine();
      printer.print("Press any key to finish").endOfLine();

      terminal.refresh();

      while (true) {
        KeyPress keyPress = terminal.pollKeyPress();
        if (keyPress == null) {
          TimeUnit.MILLISECONDS.sleep(100);
          continue;
        }
        break;
      }
    }
  }
}
